%  Scrip to check Weigth and Injected Activity from PET data
%
%
%  # Short discription: This script generates a .mat file with the injected
%      activity and weigthed of each subject
%
%  # Note: The script assums that the data is always organized in the same
%   way as in a database (please be organized).
%
%
%  #Input:
%      $ Define the correct paths and files:
% 		- main_dir -> Home directory where the data should be.
% 		- patientID -> PatientID
% 		- pet_dir -> folder with PET data
%
%
%  #Output:
%       -In each patientID directory a folder will be created (.mat)
%       with the weigth and injected activity
%
%
%  Note: the pet data can be in ECAT or DICOM format
%
% Date  : February 2014
% Author: Nuno Andre da Silva
% E-mail: n.da.silva@fz-juelich.de
%         nuno.andre.da.silva@gmail.com

% clean up
close all
clear all
clc

tic

% --- Define paths
% main_dir = '/home/afs13/Documents/data/ibeb_data/ADNI/15AD_ISMRM2014/'; % is just one
% patientID = {'ADNI_003_S_4136/','ADNI_005_S_4707/','ADNI_005_S_4910/','ADNI_016_S_4009/',...
%     'ADNI_016_S_4591/','ADNI_016_S_4887/','ADNI_027_S_4802/',...
%     'ADNI_126_S_4494/','ADNI_126_S_4686/','ADNI_127_S_4500/','ADNI_127_S_4940/'};
main_dir = '/home/afs13/Documents/data/hugo/ADNI_dataset/'; % is just one
patientID = {'ADNI_all_127_S_4940/'};

pet_dir = 'PET';


% The data is processed sequencially which means a patient after the other


for i = 1:size(patientID,2)
    
    disp(['Patient -> ' cell2str(patientID(i))])
    
    % ------------------------------------------------------- CHECK DIRECTORIES
    
    dir_of_interest = [main_dir cell2str(patientID(i)) pet_dir];
    
    % --- PET dir
    if ~exist(dir_of_interest, 'dir')
        disp(['Directory ' main_dir cell2str(patientID(i)) pet_dir ' does not exist']);
        break;
    else
        
        folder_of_interest = dir(dir_of_interest);
        folder_of_interest_subid = [folder_of_interest(:).isdir]; % 1st 3 are '.' '..' and '.DS_STORE'
        folder_of_interest = {folder_of_interest(folder_of_interest_subid).name}';
        folder_of_interest(ismember(folder_of_interest,{'.','..'})) = [];
        
    end
    
    flag_isdicom = zeros(size(folder_of_interest));
    
    % --- Check file format
    for folder_i = 1:size(folder_of_interest,1)
        
        [pathss]=check_files([main_dir cell2str(patientID(i)) pet_dir '/' cell2str(folder_of_interest(folder_i))  '/'], '*dcm');
        
        if ~isempty(pathss) % --- dicom file
            
            files_dcm=dir([cell2str(pathss) '/*.dcm']);
            
            
            header_dcm = dicominfo([cell2str(pathss) '/' files_dcm(1).name]);
            
            toCalcSUV = [];
            toCalcSUV.patient_weight = header_dcm.PatientWeight;
            toCalcSUV.dose_start_time = header_dcm.RadiopharmaceuticalInformationSequence.Item_1.RadionuclideTotalDose;
            toCalcSUV.decay_corr_fctr=header_dcm.DecayFactor;
%             if (strcmp(header_dcm.DecayCorrection,'START'))
% % % %                 toCalcSUV.decay_corr_fctr = 'data is decay corrected';
%                 toCalcSUV.decay_corr_fctr = 1;
%                 
%             else
%                 toCalcSUV.decay_corr_fctr = hd.sh.decay_corr_fctr;
%             end
            
            save([cell2str(pathss) '/' files_dcm(1).name(1:end-4) '_SUV_parameters.mat'],'toCalcSUV');
            
            
        else % --- ecat file
            
            [pathss]=check_files([main_dir cell2str(patientID(i)) pet_dir '/' cell2str(folder_of_interest(folder_i))  '/'], '*v');
            
            files_ecat=dir([cell2str(pathss) '/*.v']);
            
            [pet_data, petscaninfo, hd]=loadecat([cell2str(pathss) '/' files_ecat(1).name]);
            
            toCalcSUV = [];
            toCalcSUV.patient_weight = hd.mh.patient_weight;
            toCalcSUV.dose_start_time = hd.mh.dosage;
            toCalcSUV.decay_corr_fctr = hd.sh.decay_corr_fctr;
            
            save([cell2str(pathss) '/' files_ecat(1).name(1:end-2) '_SUV_parameters.mat'],'toCalcSUV');
            
        end
        
        
    end
    
    
end

